==> bowob-6.x-8.14.tar.gz: bowob/bowob_drupal.php <==
<?php

include(dirname(__FILE__) . "/bowob_core.php");

function bowobs_version(){
  return "6_8_14";
}

function bowobs_user_logued(){
  global $user;
  
  if($user->uid > 0){
    return true;
  }
  else{
    return false;
  }
}

function bowobs_user_id(){
  global $user;
  
  return $user->uid;
}

function bowobs_user_name(){
  global $user;

  if($user->uid > 0){
    return $user->name;
  }
  else{
    return "";
  }
}

function bowobs_user_validate($username){
  if($username == ""){
    return 1;
  }
  
  if(drupal_is_denied("user", $username)){
    return 2;
  }
  
  if(db_result(db_query("SELECT COUNT(*) FROM {users} WHERE LOWER(name) = LOWER('%s')", $username)) > 0){
    return 3;
  }
  
  return 0;
}

function bowobs_user_logued_validate(){
  return user_access("bowob chat");
}

function bowobs_redirect_index(){
  drupal_goto("");
}

function bowobs_redirect_login(){
  drupal_goto("user");
}

function bowobs_enable(){
  if(!db_table_exists("bowob")){

    $schema["bowob"] = array(
    "fields" => array(
      "id" => array(
        "type" => "serial",
        "unsigned" => TRUE,
        "not null" => TRUE),
      "sync" => array(
        "type" => "varchar",
        "length" => 50,
        "not null" => TRUE,
        "default" => ""),
      "time" => array(
        "type" => "int",
        "unsigned" => TRUE,
        "not null" => TRUE,
        "default" => 0),
      "user" => array(
        "type" => "varchar",
        "length" => 50,
        "not null" => TRUE,
        "default" => ""),
      "type" => array(
        "type" => "int",
        "unsigned" => TRUE,
        "not null" => TRUE,
        "default" => 0),
      ),
    "primary key" => array("id"),
    );

    $ret = array();
    db_create_table($ret, "bowob", $schema["bowob"]);
  }
}

function bowobs_disable(){
  if(db_table_exists("bowob")){
    $ret = array();
    db_drop_table($ret, "bowob");
  }
}

function bowobs_db_insert($sync, $time, $user, $type){
  db_query("INSERT INTO {bowob} (sync, time, user, type) VALUES ('%s', %d, '%s', %d)", $sync, $time, $user, $type);

  return db_last_insert_id("bowob", "id");
}

function bowobs_db_extract($sid, $ssync, $stime){
  db_query("DELETE FROM {bowob} WHERE time < %d", $stime);

  $rs = db_fetch_object(db_query("SELECT sync, user, type FROM {bowob} WHERE id = %d AND sync = '%s'", $sid, $ssync));
  
  if(!$rs || $rs->sync != $ssync){
    return array();
  }
  else{
    db_query("DELETE FROM {bowob} WHERE id = %d", $sid);
    return array($rs->user, $rs->type);
  }
}

function bowobs_menu(){
  $items["bowob"] = array(
    "title" => t("Chat"),
    "page callback" => "drupal_get_form",
    "page arguments" => array("bowobs_login"),
    "access callback" => "bowobs_menu_bowob_access"
  );

  return $items;
}

function bowobs_menu_bowob_access(){
  global $user, $bowob_chat_onlyreg;
  
  if($bowob_chat_onlyreg && $user->uid){
    return bowobs_user_logued_validate();
  }
  else{
    return true;
  }
}

function bowobs_login(){
  if(isset($_POST["username"])){
    bowobf_loginsubmit($_POST["username"]);
  }
  
  return bowobf_login();
}

function bowobs_login_submit($form_id, $form_values){
  bowobf_loginsubmit($form_values["username"]);
}

function bowobs_block($page, $op, $delta){
  if($op == "list"){
    $blocks[0]["info"] = t("BoWoB Link");
    $blocks[1]["info"] = t("BoWoB Login");

    return $blocks;
  }
  else if($op == "view" && $page != "bowob"){
    $block = array();
    $block["subject"] = t("Chat");
    if($delta == 0){
      $block["content"] = drupal_get_form("bowobf_linkblock");
    }
    else{
      $block["content"] = drupal_get_form("bowobf_loginblock");
    }

    return $block;
  }
}

function bowobs_form_blocklink(){
  $items = array();
  
  $items[] = l(t("Chat"), "bowob", array("title" => t("Chat")));
  $form["links"] = array("#value" => theme("item_list", $items));

  return $form;
}

function bowobs_form_blocklogin(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 15,
    "#required" => TRUE,
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
  );
  
  return $form;
}

function bowobs_form_login(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#weight" => 2,
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 60,
    "#required" => TRUE,
    "#description" => t("Enter your @s username.", array("@s" => variable_get("site_name", "Drupal"))),
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
    "#weight" => 3,
  );

  return $form;
}

function bowobs_form_error($type, $username){
  if($type == 1){
    form_set_error("username", t("!name field is required.", array("!name" => t("Username"))));
  }
  elseif($type == 2){
    form_set_error("username", t("The name %name is a reserved username.", array("%name" => $username)));
  }
  elseif($type == 3){
    form_set_error("username", t("The name %name is already taken.", array("%name" => $username)));
  }
}

function bowobs_cookie_get($value){
  return $value;
}

?>

==> bowob-6.x-9.0.tar.gz: bowob/bowob_drupal.php <==
<?php

include(dirname(__FILE__) . "/bowob_core.php");

define("USERNAME_MAX_LENGTH", 60);
//define("BOWOB_UR_RELATION_TYPE_ID", 0);

function bowobs_user_logued(){
  global $user;
  
  if($user->uid > 0){
    return true;
  }
  else{
    return false;
  }
}

function bowobs_user_id(){
  global $user;
  
  return $user->uid;
}

function bowobs_user_name(){
  global $user;

  if($user->uid > 0){
    return $user->name;
  }
  else{
    return "";
  }
}

function bowobs_user_visiblename()
{
  return "";
}

function bowobs_user_avatar()
{
  global $user;
  
  if($user->uid > 0){
    if(empty($user->picture)){
      return "";
    }
    else{
      return base_path() . $user->picture;
    }
  }
  else{
    return "";
  }
}

function bowobs_user_friends($id, $separator){
  $output = "";

  if(function_exists("user_relationships_load")){
    $friends = array();
    $args = array(
      "user" => $id,
      "approved" => true,
    );
    if(defined("BOWOB_UR_RELATION_TYPE_ID")){
      $args["rtid"] = BOWOB_UR_RELATION_TYPE_ID;
    }
    $query_opts = array("include_user_info" => true);

    $relationships = user_relationships_load($args, $query_opts);
    if($relationships){
      foreach ($relationships as $rtid => $relationship) {
        if ($id == $relationship->requester_id) {
          $relatee = $relationship->requestee;
        }
        else {
          $relatee = $relationship->requester;
        }

        $friends[] = $relatee->name;
      }
    }

    $friends = array_unique($friends);

    $count = sizeof($friends);
    for($i = 0; $i < $count; $i ++){
      $output .= $friends[$i] . $separator;
    }
  }
  
  return $output;
}

function bowobs_user_validate($username){
  if($username == ""){
    return 1;
  }
  
  if(drupal_is_denied("user", $username)){
    return 2;
  }
  
  if(db_result(db_query("SELECT COUNT(*) FROM {users} WHERE LOWER(name) = LOWER('%s')", $username)) > 0){
    return 3;
  }
  
  return 0;
}

function bowobs_user_logued_validate(){
  return user_access("bowob chat");
}

function bowobs_redirect_index(){
  drupal_goto("");
}

function bowobs_redirect_login(){
  drupal_goto("user");
}

function bowobs_redirect_profile($userid){
  if(!is_numeric($userid)){
    bowobs_redirect_index();
  }
  
  drupal_goto("user/" . $userid);
}

function bowobs_enable(){
  if(!db_table_exists("bowob")){

    $schema["bowob"] = array(
    "fields" => array(
      "id" => array(
        "type" => "serial",
        "unsigned" => TRUE,
        "not null" => TRUE),
      "sync" => array(
        "type" => "varchar",
        "length" => 50,
        "not null" => TRUE,
        "default" => ""),
      "time" => array(
        "type" => "int",
        "unsigned" => TRUE,
        "not null" => TRUE,
        "default" => 0),
      "user" => array(
        "type" => "varchar",
        "length" => 50,
        "not null" => TRUE,
        "default" => ""),
      "name" => array(
        "type" => "varchar",
        "length" => 50,
        "not null" => TRUE,
        "default" => ""),
      "avatar" => array(
        "type" => "varchar",
        "length" => 200,
        "not null" => TRUE,
        "default" => ""),
      "type" => array(
        "type" => "int",
        "unsigned" => TRUE,
        "not null" => TRUE,
        "default" => 0),
      "user_id" => array(
        "type" => "int",
        "unsigned" => TRUE,
        "not null" => TRUE,
        "default" => 0),
      ),
    "primary key" => array("id"),
    );

    $ret = array();
    db_create_table($ret, "bowob", $schema["bowob"]);
  }
}

function bowobs_disable(){
  if(db_table_exists("bowob")){
    $ret = array();
    db_drop_table($ret, "bowob");
  }
}

function bowobs_db_insert($sync, $time, $user, $name, $avatar, $type, $user_id){
  db_query("INSERT INTO {bowob} (sync, time, user, name, avatar, type, user_id) VALUES ('%s', %d, '%s', '%s', '%s', %d, %d)", $sync, $time, $user, $name, $avatar, $type, $user_id);

  return db_last_insert_id("bowob", "id");
}

function bowobs_db_extract($sid, $ssync, $stime){
  db_query("DELETE FROM {bowob} WHERE time < %d", $stime);

  $rs = db_fetch_object(db_query("SELECT sync, user, type, user_id, name, avatar FROM {bowob} WHERE id = %d AND sync = '%s'", $sid, $ssync));
  
  if(!$rs || $rs->sync != $ssync){
    return array();
  }
  else{
    db_query("DELETE FROM {bowob} WHERE id = %d", $sid);
    return array($rs->user, $rs->type, $rs->user_id, $rs->name, $rs->avatar);
  }
}

function bowobs_menu(){
  $items["bowob"] = array(
    "title" => t("Chat"),
    "page callback" => "drupal_get_form",
    "page arguments" => array("bowobs_login"),
    "access callback" => "bowobs_menu_bowob_access"
  );

  return $items;
}

function bowobs_menu_bowob_access(){
  global $user, $bowob_chat_onlyreg;
  
  if($bowob_chat_onlyreg && $user->uid){
    return bowobs_user_logued_validate();
  }
  else{
    return true;
  }
}

function bowobs_login(){
  if(isset($_POST["username"])){
    bowobf_loginsubmit($_POST["username"]);
  }
  
  return bowobf_login();
}

function bowobs_login_submit($form_id, $form_values){
  bowobf_loginsubmit($form_values["username"]);
}

function bowobs_block($page, $op, $delta){
  if($op == "list"){
    $blocks[0]["info"] = t("BoWoB Link");
    $blocks[1]["info"] = t("BoWoB Login");

    return $blocks;
  }
  else if($op == "view" && $page != "bowob"){
    $block = array();
    $block["subject"] = t("Chat");
    if($delta == 0){
      $block["content"] = drupal_get_form("bowobf_linkblock");
    }
    else{
      $block["content"] = drupal_get_form("bowobf_loginblock");
    }

    return $block;
  }
}

function bowobs_form_blocklink(){
  $items = array();
  
  $items[] = l(t("Chat"), "bowob", array("title" => t("Chat")));
  $form["links"] = array("#value" => theme("item_list", $items));

  return $form;
}

function bowobs_form_blocklogin(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 15,
    "#required" => TRUE,
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
  );
  
  return $form;
}

function bowobs_form_login(){
  $form = array(
    "#action" => url("bowob"),
    "#id" => "bowob-login-form",
    "#base" => "bowobs_login",
  );

  $form["username"] = array(
    "#type" => "textfield",
    "#weight" => 2,
    "#title" => t("Username"),
    "#maxlength" => USERNAME_MAX_LENGTH,
    "#size" => 60,
    "#required" => TRUE,
    "#description" => t("Enter your @s username.", array("@s" => variable_get("site_name", "Drupal"))),
  );

  $form["submit"] = array(
    "#type" => "submit",
    "#value" => t("Chat"),
    "#weight" => 3,
  );

  return $form;
}

function bowobs_form_error($type, $username){
  if($type == 1){
    form_set_error("username", t("!name field is required.", array("!name" => t("Username"))));
  }
  elseif($type == 2){
    form_set_error("username", t("The name %name is a reserved username.", array("%name" => $username)));
  }
  elseif($type == 3){
    form_set_error("username", t("The name %name is already taken.", array("%name" => $username)));
  }
}

function bowobs_cookie_get($name, $default)
{
  if(isset($_COOKIE[$name])){
    return $_COOKIE[$name];
  }
  else{
    return $default;
  }
}

function bowobs_cookie_set($name, $value, $time, $path, $host)
{
  setcookie($name, $value, $time, $path, $host);
}

function bowobs_stylesheet($base_url, $file, $name, $conditional = ""){
  $path = base_path() . drupal_get_path("module", "bowob") . "/" . $file;
  $content = "";

  if(!empty($conditional)){
    $content .= "<!--[if " . $conditional . "]>";
  }
  $content .= "<link rel=\"stylesheet\" href=\"" . $path . "\" type=\"text/css\" media=\"all\" />";
  if(!empty($conditional)){
    $content .= "<![endif]-->";
  }
  
  drupal_set_html_head($content);
}

function bowobs_incfile($file)
{
  include(dirname(__FILE__) . "/" . $file . ".php");
}

function bowobs_httphead($prop, $value)
{
  header($prop . ": " . $value);
}

?>
